# BorisML

BorisML is a PIP package for self-supervised active learning.

> We, at [WhatToLabel](https://www.whattolabel.com), are passionate engineers who want to make deep learning more efficient. We want to help popularize the use of self-supervised methods to understand and filter raw image data. Our solution can be applied before any data annotation step and the learned representations can be used to analyze and visualize datasets as well as for selecting a core set of samples.

> Our active-learning library is powered by state-of-the-art algorithms to help you with interactive learning loops.

If you are curious to learn more about our work - check out [WhatToLabel](https://www.whattolabel.com)!

# Installation:

```
pip install borisml
```

# Documentation
For more information, take a look at the [Documentation](https://www.notion.so/whattolabel/WhatToLabel-Documentation-28e645f5564a453e807d0a384a4e6ea7).